PAWpySeed: pawpyseed.core.wavefunction.CoreRegion Class Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Member Functions | Public Attributes | List of all members
pawpyseed.core.wavefunction.CoreRegion Class Reference

## Public Member Functions
def | __init__ (self, potcar)

## Public Attributes
| pps

## Detailed Description

    List of Pseudopotential objects to describe the core region of a structure.

    Attributes:
        pps (dict of Pseudopotential): keys are element symbols,
            values are Pseudopotential objects

## Constructor & Destructor Documentation

def pawpyseed.core.wavefunction.CoreRegion.__init__ | ( |  | self,
|  |  | potcar
| ) |  |

    Returns a new CoreRegion object from a
    pymatgen.io.vasp.inputs.Potcar class.

    Arguments:
        potcar (pymatgen.io.vasp.inputs.Potcar): Potcar file for
    the VASP calculation

    Returns:
        CoreRegion object based on potcar

## Member Data Documentation

pawpyseed.core.wavefunction.CoreRegion.pps

The documentation for this class was generated from the following file:

- /home/kyle/Research/projects/pawpyseed/pawpyseed/core/wavefunction.py